@@ -6,9 +6,10 @@
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <time.h>
 #include <unistd.h>
-#include "string.h"
+#include "str.h"
 #include "unicode.h"
 #include "util.h"
 
@@ -104,7 +105,7 @@ static void parse_preamble(struct parser *p) {
 	} else {
 		date_time = time(NULL);
 	}
-	struct tm *date_tm = localtime(&date_time);
+	struct tm *date_tm = gmtime(&date_time);
 	strftime(date, sizeof(date), "%F", date_tm);
 	while ((ch = parser_getch(p)) != UTF8_INVALID) {
 		if ((ch < 0x80 && isalnum(ch)) || ch == '_' || ch == '-' || ch == '.') {
@@ -480,6 +481,8 @@ static void parse_table(struct parser *p, uint32_t style) {
 				++column;
 			}
 			break;
+		case ' ':
+			goto continue_cell;
 		default:
 			parser_fatal(p, "Expected either '|' or ':'");
 			break;
@@ -515,6 +518,7 @@ static void parse_table(struct parser *p, uint32_t style) {
 			break;
 		}
 		curcell->contents = str_create();
+continue_cell:
 		switch (ch = parser_getch(p)) {
 		case ' ':
 			// Read out remainder of the text
@@ -686,7 +690,10 @@ static void output_scdoc_preamble(struct parser *p) {
 }
 
 int main(int argc, char **argv) {
-	if (argc > 1) {
+	if (argc == 2 && strcmp(argv[1], "-v") == 0) {
+		printf("scdoc " VERSION "\n");
+		return 0;
+	} else if (argc > 1) {
 		fprintf(stderr, "Usage: scdoc < input.scd > output.roff\n");
 		return 1;
 	}
